@@ -38,7 +38,8 @@ class Node(FastAPI):
         async def on_connect():
             logging.debug('received "on_connect" from constructor event.')
             self.reset()
-            await self.update_state(State.Idle)
+            state = self.get_state()
+            await self.update_state(state)
 
         @self.sio_client.on('disconnect')
         async def on_disconnect():
@@ -61,6 +62,9 @@ class Node(FastAPI):
     def reset(self):
         self.status = Status(id=self.uuid, name=self.name)
 
+    async def get_state(self):
+        raise Exception("Override this in subclass")
+
     async def connect(self):
         try:
             await self.sio_client.disconnect()
@@ -105,7 +109,7 @@ class Node(FastAPI):
         raise Exception("Override this in subclass")
 
     @staticmethod
-    def create_project_folder(context:Context) -> str:
+    def create_project_folder(context: Context) -> str:
         project_folder = f'/data/{context.organization}/{context.project}'
         os.makedirs(project_folder, exist_ok=True)
         return project_folder
